```
Usage: vcd vapp network services dhcp set [OPTIONS] <vapp-name> <network-name>

Options:
  -i, --ip-range <ip>             IP range in StartAddress-EndAddress format
                                  [required]
  -dlt, --default-lease-time <ip>
                                  default lease time
  -mlt, --max-lease-time <ip>     max lease time
  -h, --help                      Show this message and exit.

```
